@@ -1,5 +1,6 @@
 require 'json'
 require 'rest-client'
+
 module Kubeclient
   # Common methods
   # this is mixed in by other gems
@@ -56,7 +57,8 @@ module Kubeclient
       auth_options: DEFAULT_AUTH_OPTIONS,
       socket_options: DEFAULT_SOCKET_OPTIONS,
       timeouts: DEFAULT_TIMEOUTS,
-      http_proxy_uri: DEFAULT_HTTP_PROXY_URI
+      http_proxy_uri: DEFAULT_HTTP_PROXY_URI,
+      as: :ros
     )
       validate_auth_options(auth_options)
       handle_uri(uri, path)
@@ -72,6 +74,7 @@ module Kubeclient
       # @timeouts[:foo] == nil resulting in infinite timeout.
       @timeouts = DEFAULT_TIMEOUTS.merge(timeouts)
       @http_proxy_uri = http_proxy_uri ? http_proxy_uri.to_s : nil
+      @as = as
 
       if auth_options[:bearer_token]
         bearer_token(@auth_options[:bearer_token])
@@ -242,7 +245,11 @@ module Kubeclient
       WATCH_ARGUMENTS.each { |k, v| params[k] = options[v] if options[v] }
       uri.query = URI.encode_www_form(params) if params.any?
 
-      Kubeclient::Common::WatchStream.new(uri, http_options(uri), as: options[:as] || :ros)
+      Kubeclient::Common::WatchStream.new(
+        uri,
+        http_options(uri),
+        formatter: ->(value) { format_response(options[:as] || @as, value) }
+      )
     end
 
     # Accepts the following options:
@@ -261,19 +268,7 @@ module Kubeclient
         rest_client[ns_prefix + resource_name]
           .get({ 'params' => params }.merge(@headers))
       end
-      return response.body if options[:as] == :raw
-
-      result = JSON.parse(response)
-
-      resource_version =
-        result.fetch('resourceVersion') do
-          result.fetch('metadata', {}).fetch('resourceVersion', nil)
-        end
-
-      # result['items'] might be nil due to https://github.com/kubernetes/kubernetes/issues/13096
-      collection = result['items'].to_a.map { |item| Kubeclient::Resource.new(item) }
-
-      Kubeclient::Common::EntityList.new(entity_type, resource_version, collection)
+      format_response(options[:as] || @as, response.body, entity_type)
     end
 
     # Accepts the following options:
@@ -286,7 +281,7 @@ module Kubeclient
         rest_client[ns_prefix + resource_name + "/#{name}"]
           .get(@headers)
       end
-      format_response(options[:as], response)
+      format_response(options[:as] || @as, response.body)
     end
 
     # delete_options are passed as a JSON payload in the delete request
@@ -305,7 +300,7 @@ module Kubeclient
           )
         )
       end
-      format_response(:ros, response)
+      format_response(@as, response.body)
     end
 
     def create_entity(entity_type, resource_name, entity_config)
@@ -326,7 +321,7 @@ module Kubeclient
         rest_client[ns_prefix + resource_name]
           .post(hash.to_json, { 'Content-Type' => 'application/json' }.merge(@headers))
       end
-      format_response(:ros, response)
+      format_response(@as, response.body)
     end
 
     def update_entity(resource_name, entity_config)
@@ -336,7 +331,7 @@ module Kubeclient
         rest_client[ns_prefix + resource_name + "/#{name}"]
           .put(entity_config.to_h.to_json, { 'Content-Type' => 'application/json' }.merge(@headers))
       end
-      format_response(:ros, response)
+      format_response(@as, response.body)
     end
 
     def patch_entity(resource_name, name, patch, namespace = nil)
@@ -348,7 +343,7 @@ module Kubeclient
             { 'Content-Type' => 'application/strategic-merge-patch+json' }.merge(@headers)
           )
       end
-      format_response(:ros, response)
+      format_response(@as, response.body)
     end
 
     def all_entities(options = {})
@@ -365,10 +360,15 @@ module Kubeclient
       end
     end
 
-    def get_pod_log(pod_name, namespace, container: nil, previous: false)
+    def get_pod_log(pod_name, namespace,
+                    container: nil, previous: false,
+                    timestamps: false, since_time: nil, tail_lines: nil)
       params = {}
       params[:previous] = true if previous
       params[:container] = container if container
+      params[:timestamps] = timestamps if timestamps
+      params[:sinceTime] = format_datetime(since_time) if since_time
+      params[:tailLines] = tail_lines if tail_lines
 
       ns = build_namespace_prefix(namespace)
       handle_exception do
@@ -389,7 +389,7 @@ module Kubeclient
       uri.path += "/#{@api_version}/#{ns}pods/#{pod_name}/log"
       uri.query = URI.encode_www_form(params)
 
-      Kubeclient::Common::WatchStream.new(uri, http_options(uri), as: :raw)
+      Kubeclient::Common::WatchStream.new(uri, http_options(uri), formatter: ->(value) { value })
     end
 
     def proxy_url(kind, name, port, namespace = '')
@@ -432,11 +432,45 @@ module Kubeclient
 
     private
 
-    def format_response(as, response)
-      return response.body if as == :raw
+    # Format ditetime according to RFC3339
+    def format_datetime(value)
+      case value
+      when DateTime, Time
+        value.strftime('%FT%T.%9N%:z')
+      when String
+        value
+      else
+        raise ArgumentError, "unsupported type '#{value.class}' of time value '#{value}'"
+      end
+    end
 
-      result = JSON.parse(response)
-      Kubeclient::Resource.new(result)
+    def format_response(as, body, list_type = nil)
+      case as
+      when :raw
+        body
+      when :parsed
+        JSON.parse(body)
+      when :parsed_symbolized
+        JSON.parse(body, symbolize_names: true)
+      when :ros
+        result = JSON.parse(body)
+
+        if list_type
+          resource_version =
+            result.fetch('resourceVersion') do
+              result.fetch('metadata', {}).fetch('resourceVersion', nil)
+            end
+
+          # result['items'] might be nil due to https://github.com/kubernetes/kubernetes/issues/13096
+          collection = result['items'].to_a.map { |item| Kubeclient::Resource.new(item) }
+
+          Kubeclient::Common::EntityList.new(list_type, resource_version, collection)
+        else
+          Kubeclient::Resource.new(result)
+        end
+      else
+        raise ArgumentError, "Unsupported format #{as.inspect}"
+      end
     end
 
     def load_entities
