@@ -1,4 +1,5 @@
 require_relative 'test_helper'
+require 'yaml'
 
 # Testing Kubernetes client configuration
 class KubeclientConfigTest < MiniTest::Test
@@ -14,6 +15,34 @@ class KubeclientConfigTest < MiniTest::Test
     check_context(config.context, ssl: true)
   end
 
+  def test_allinone_nopath
+    yaml = File.read(config_file('allinone.kubeconfig'))
+    # A self-contained config shouldn't depend on kcfg_path.
+    config = Kubeclient::Config.new(YAML.safe_load(yaml), nil)
+    assert_equal(['default/localhost:8443/system:admin'], config.contexts)
+    check_context(config.context, ssl: true)
+  end
+
+  def test_external_nopath
+    yaml = File.read(config_file('external.kubeconfig'))
+    # kcfg_path = nil should prevent file access
+    config = Kubeclient::Config.new(YAML.safe_load(yaml), nil)
+    assert_raises(StandardError) do
+      config.context.ssl_options
+    end
+  end
+
+  def test_external_nopath_absolute
+    yaml = File.read(config_file('external.kubeconfig'))
+    # kcfg_path = nil should prevent file access, even if absolute path specified
+    ca_absolute_path = File.absolute_path(config_file('external.kubeconfig').path)
+    yaml = yaml.gsub('external-ca.pem', ca_absolute_path)
+    config = Kubeclient::Config.new(YAML.safe_load(yaml), nil)
+    assert_raises(StandardError) do
+      config.context.ssl_options
+    end
+  end
+
   def test_nouser
     config = Kubeclient::Config.read(config_file('nouser.kubeconfig'))
     assert_equal(['default/localhost:8443/nouser'], config.contexts)
@@ -39,11 +68,17 @@ class KubeclientConfigTest < MiniTest::Test
     assert_equal('pAssw0rd123', context.auth_options[:password])
   end
 
+  def test_timestamps
+    # Test YAML parsing doesn't crash on YAML timestamp syntax.
+    Kubeclient::Config.read(config_file('timestamps.kubeconfig'))
+  end
+
   private
 
   def check_context(context, ssl: true)
     assert_equal('https://localhost:8443', context.api_endpoint)
     assert_equal('v1', context.api_version)
+    assert_equal('default', context.namespace)
     if ssl
       assert_equal(OpenSSL::SSL::VERIFY_PEER, context.ssl_options[:verify_ssl])
       assert_kind_of(OpenSSL::X509::Store, context.ssl_options[:cert_store])
