@@ -18,7 +18,7 @@ class TestWatch < MiniTest::Test
     client = Kubeclient::Client.new('http://localhost:8080/api/', 'v1')
 
     client.watch_pods.to_enum.with_index do |notice, index|
-      assert_instance_of(Kubeclient::Common::WatchNotice, notice)
+      assert_instance_of(Kubeclient::Resource, notice)
       assert_equal(expected[index]['type'], notice.type)
       assert_equal('Pod', notice.object.kind)
       assert_equal('php', notice.object.metadata.name)
@@ -62,24 +62,13 @@ class TestWatch < MiniTest::Test
       .to_return(body: open_test_file('pod_log.txt'),
                  status: 200)
 
-    stream = Kubeclient::Common::WatchStream.new(URI.parse(url), {}, as: :raw)
+    stream = Kubeclient::Common::WatchStream.new(URI.parse(url), {}, formatter: ->(v) { v })
     stream.to_enum.with_index do |line, index|
       assert_instance_of(String, line)
       assert_equal(expected_lines[index], line)
     end
   end
 
-  # Ensure that WatchStream respects a format that's not JSON
-  def test_watch_stream_unknown
-    url = 'http://www.example.com/foobar'
-    stub_request(:get, url)
-      .to_return(body: open_test_file('pod_log.txt'),
-                 status: 200)
-
-    stream = Kubeclient::Common::WatchStream.new(URI.parse(url), {}, as: :foo)
-    assert_raises(NotImplementedError) { stream.each {} }
-  end
-
   def test_watch_with_resource_version
     api_host = 'http://localhost:8080/api'
     version = '1995'
@@ -143,10 +132,10 @@ class TestWatch < MiniTest::Test
     client = Kubeclient::Client.new(api_host, 'v1')
     watcher = client.watch_events
 
-    # explodes when Errno::EBADF is not caught
+    # explodes when StandardError is not caught
     watcher.each do
       watcher.finish
-      raise Errno::EBADF
+      raise StandardError
     end
 
     assert_requested(:get, "#{api_host}/v1/watch/events", times: 1)
